@@ -7,7 +7,7 @@
 #  define AVOGADROIO_NO_EXPORT
 #else
 #  ifndef AVOGADROIO_EXPORT
-#    ifdef AvogadroIO_EXPORTS
+#    ifdef IO_EXPORTS
         /* We are building this library */
 #      define AVOGADROIO_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,13 +23,20 @@
 
 #ifndef AVOGADROIO_DEPRECATED
 #  define AVOGADROIO_DEPRECATED __attribute__ ((__deprecated__))
-#  define AVOGADROIO_DEPRECATED_EXPORT AVOGADROIO_EXPORT __attribute__ ((__deprecated__))
-#  define AVOGADROIO_DEPRECATED_NO_EXPORT AVOGADROIO_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AVOGADROIO_NO_DEPRECATED
+#ifndef AVOGADROIO_DEPRECATED_EXPORT
+#  define AVOGADROIO_DEPRECATED_EXPORT AVOGADROIO_EXPORT AVOGADROIO_DEPRECATED
 #endif
 
+#ifndef AVOGADROIO_DEPRECATED_NO_EXPORT
+#  define AVOGADROIO_DEPRECATED_NO_EXPORT AVOGADROIO_NO_EXPORT AVOGADROIO_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AVOGADROIO_NO_DEPRECATED
+#    define AVOGADROIO_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* AVOGADROIO_EXPORT_H */
