@@ -7,7 +7,7 @@
 #  define AVOGADROQUANTUMIO_NO_EXPORT
 #else
 #  ifndef AVOGADROQUANTUMIO_EXPORT
-#    ifdef AvogadroQuantumIO_EXPORTS
+#    ifdef QuantumIO_EXPORTS
         /* We are building this library */
 #      define AVOGADROQUANTUMIO_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,13 +23,20 @@
 
 #ifndef AVOGADROQUANTUMIO_DEPRECATED
 #  define AVOGADROQUANTUMIO_DEPRECATED __attribute__ ((__deprecated__))
-#  define AVOGADROQUANTUMIO_DEPRECATED_EXPORT AVOGADROQUANTUMIO_EXPORT __attribute__ ((__deprecated__))
-#  define AVOGADROQUANTUMIO_DEPRECATED_NO_EXPORT AVOGADROQUANTUMIO_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AVOGADROQUANTUMIO_NO_DEPRECATED
+#ifndef AVOGADROQUANTUMIO_DEPRECATED_EXPORT
+#  define AVOGADROQUANTUMIO_DEPRECATED_EXPORT AVOGADROQUANTUMIO_EXPORT AVOGADROQUANTUMIO_DEPRECATED
 #endif
 
+#ifndef AVOGADROQUANTUMIO_DEPRECATED_NO_EXPORT
+#  define AVOGADROQUANTUMIO_DEPRECATED_NO_EXPORT AVOGADROQUANTUMIO_NO_EXPORT AVOGADROQUANTUMIO_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AVOGADROQUANTUMIO_NO_DEPRECATED
+#    define AVOGADROQUANTUMIO_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* AVOGADROQUANTUMIO_EXPORT_H */
